@@ -1,13 +1,3 @@
-'''
-Actions
--------
-0 - forward
-1 - backward
-2 - left rotation
-3 - right rotation
-'''
-
-
 # wrapper class including the agents and the environment
 # avoid having to manipulate the environment by yourself
 class Turtle:
@@ -17,4 +7,8 @@ class Turtle:
         self.agent = agent
 
     def execute(self, action):
-        return self.env.step(self.agent, action)
\ No newline at end of file
+        feedback = self.env.step(self.agent, action)
+        return feedback
+
+    def getNumberOfActions(self):
+        return self.env.nbActions
